@@ -5,7 +5,7 @@ use strict;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2023-09-09'; # DATE
 our $DIST = 'Sah-Schemas-Re'; # DIST
-our $VERSION = '0.004'; # VERSION
+our $VERSION = '0.005'; # VERSION
 
 our $schema = [any => {
     summary => 'Regex (convertable from string of the form `/.../`) or coderef (convertable from string of the form `sub { ... }`)',
@@ -13,29 +13,30 @@ our $schema = [any => {
 
 Either Regexp object or coderef is accepted.
 
-Coercion from string is available for Regexp If string is of the form of `/.../`
-or `qr(...)`, then it will be compiled into a Regexp object. If the regex
-pattern inside `/.../` or `qr(...)` is invalid, value will be rejected.
-Currently, unlike in normal Perl, for the `qr(...)` form, only parentheses `(`
-and `)` are allowed as the delimiter. Currently modifiers `i`, `m`, and `s`
-after the second `/` are allowed.
+Coercion from string for Regexp is available if string is of the form of `/.../`
+or `qr(...)`; it will be compiled into a Regexp object. If the regex pattern
+inside `/.../` or `qr(...)` is invalid, value will be rejected. Currently,
+unlike in normal Perl, for the `qr(...)` form, only parentheses `(` and `)` are
+allowed as the delimiter. Currently modifiers `i`, `m`, and `s` after the second
+`/` are allowed.
 
-Coercion from string is available for coderef if string matches the regex
+Coercion from string for coderef is available if string matches the regex
 `qr/\Asub\s*\{.*\}\z/s`, then it will be eval'ed into a coderef. If the code
 fails to compile, the value will be rejected. Note that this means you accept
 arbitrary code from the user to execute! Please make sure first and foremost
 that this is acceptable in your case. Currently string is eval'ed in the `main`
 package, without `use strict` or `use warnings`.
 
-Coercion from string to regex literal is also available for other forms of
-string.
+Unlike the default behavior of the `re` Sah type, coercion from other string not
+in the form of `/.../` or `qr(...)` is not available. Thus, such values will be
+rejected.
 
 This schema is handy if you want to accept regex or coderef from the
 command-line.
 
 _
     of => [
-        ['re'],
+        ['obj::re'],
         ['code'],
     ],
 
@@ -45,18 +46,18 @@ _
     ],
 
     examples => [
-        {value=>'', valid=>1, summary=>'Converted to regex'},
-        {value=>'a', valid=>1, summary=>'Converted to regex'},
+        {value=>'', valid=>0, summary=>'Not to regex or code'},
+        {value=>'a', valid=>0, summary=>'Not a regex or code'},
         {value=>{}, valid=>0, summary=>'Not a regex or code'},
         {value=>qr//, valid=>1},
         {value=>sub{}, valid=>1},
 
         # re
         {value=>'//', valid=>1, validated_value=>qr//},
-        #{value=>'/foo', valid=>0, summary=>'Not converted to regex'},
-        #{value=>'qr(foo', valid=>0, summary=>'Not converted to regex'},
-        #{value=>'qr(foo(', valid=>0, summary=>'Not converted to regex'},
-        #{value=>'qr/foo/', valid=>0, summary=>'Not converted to regex'},
+        {value=>'/foo', valid=>0, summary=>'Not converted to regex'},
+        {value=>'qr(foo', valid=>0, summary=>'Not converted to regex'},
+        {value=>'qr(foo(', valid=>0, summary=>'Not converted to regex'},
+        {value=>'qr/foo/', valid=>0, summary=>'Not converted to regex'},
 
         {value=>'/foo.*/', valid=>1, validated_value=>qr/foo.*/},
         {value=>'qr(foo.*)', valid=>1, validated_value=>qr/foo.*/},
@@ -68,7 +69,7 @@ _
         # code
         {value=>'sub {}', valid=>1, code_validate=>sub { ref($_[0]) eq 'CODE' & !defined($_[0]->()) }},
         {value=>'sub{"foo"}', valid=>1, code_validate=>sub { ref($_[0]) eq 'CODE' && $_[0]->() eq 'foo' }},
-        #{value=>'sub {', valid=>0, summary=>'Not converted to code'},
+        {value=>'sub {', valid=>0, summary=>'Not converted to code'},
 
         {value=>'sub {1=2}', valid=>0, summary=>'Code does not compile'},
     ],
@@ -90,15 +91,15 @@ Sah::Schema::re_or_code_from_str - Regex (convertable from string of the form `/
 
 =head1 VERSION
 
-This document describes version 0.004 of Sah::Schema::re_or_code_from_str (from Perl distribution Sah-Schemas-Re), released on 2023-09-09.
+This document describes version 0.005 of Sah::Schema::re_or_code_from_str (from Perl distribution Sah-Schemas-Re), released on 2023-09-09.
 
 =head1 SYNOPSIS
 
 =head2 Sample data and validation results against this schema
 
- ""  # valid (Converted to regex)
+ ""  # INVALID (Not to regex or code)
 
- "a"  # valid (Converted to regex)
+ "a"  # INVALID (Not a regex or code)
 
  {}  # INVALID (Not a regex or code)
 
@@ -108,6 +109,14 @@ This document describes version 0.004 of Sah::Schema::re_or_code_from_str (from
 
  "//"  # valid, becomes qr()
 
+ "/foo"  # INVALID (Not converted to regex)
+
+ "qr(foo"  # INVALID (Not converted to regex)
+
+ "qr(foo("  # INVALID (Not converted to regex)
+
+ "qr/foo/"  # INVALID (Not converted to regex)
+
  "/foo.*/"  # valid, becomes qr(foo.*)
 
  "qr(foo.*)"  # valid, becomes qr(foo.*)
@@ -122,6 +131,8 @@ This document describes version 0.004 of Sah::Schema::re_or_code_from_str (from
 
  "sub{\"foo\"}"  # valid
 
+ "sub {"  # INVALID (Not converted to code)
+
  "sub {1=2}"  # INVALID (Code does not compile)
 
 =head2 Using with Data::Sah
@@ -140,12 +151,12 @@ valid, a non-empty error message otherwise):
  my $errmsg = $validator->($data);
  
  # a sample valid data
- $data = "";
+ $data = qr();
  my $errmsg = $validator->($data); # => ""
  
  # a sample invalid data
- $data = "/foo[/";
- my $errmsg = $validator->($data); # => "Invalid regex: Unmatched [ in regex; marked by <-- HERE in m/foo[ <-- HERE / at (eval 2366) line 1.\n"
+ $data = "qr(foo(";
+ my $errmsg = $validator->($data); # => "Not of type object"
 
 Often a schema has coercion rule or default value rules, so after validation the
 validated value will be different from the original. To return the validated
@@ -155,12 +166,12 @@ validated value will be different from the original. To return the validated
  my $res = $validator->($data); # [$errmsg, $validated_val]
  
  # a sample valid data
- $data = "";
- my $res = $validator->($data); # => ["",""]
+ $data = qr();
+ my $res = $validator->($data); # => ["",qr()]
  
  # a sample invalid data
- $data = "/foo[/";
- my $res = $validator->($data); # => ["Invalid regex: Unmatched [ in regex; marked by <-- HERE in m/foo[ <-- HERE / at (eval 2379) line 1.\n","/foo[/"]
+ $data = "qr(foo(";
+ my $res = $validator->($data); # => ["Not of type object","qr(foo("]
 
 Data::Sah can also create validator that returns a hash of detailed error
 message. Data::Sah can even create validator that targets other language, like
@@ -257,22 +268,23 @@ L<Type::Tiny> as well as L<Type::FromSah>):
 
 Either Regexp object or coderef is accepted.
 
-Coercion from string is available for Regexp If string is of the form of C</.../>
-or C<qr(...)>, then it will be compiled into a Regexp object. If the regex
-pattern inside C</.../> or C<qr(...)> is invalid, value will be rejected.
-Currently, unlike in normal Perl, for the C<qr(...)> form, only parentheses C<(>
-and C<)> are allowed as the delimiter. Currently modifiers C<i>, C<m>, and C<s>
-after the second C</> are allowed.
+Coercion from string for Regexp is available if string is of the form of C</.../>
+or C<qr(...)>; it will be compiled into a Regexp object. If the regex pattern
+inside C</.../> or C<qr(...)> is invalid, value will be rejected. Currently,
+unlike in normal Perl, for the C<qr(...)> form, only parentheses C<(> and C<)> are
+allowed as the delimiter. Currently modifiers C<i>, C<m>, and C<s> after the second
+C</> are allowed.
 
-Coercion from string is available for coderef if string matches the regex
+Coercion from string for coderef is available if string matches the regex
 C<qr/\Asub\s*\{.*\}\z/s>, then it will be eval'ed into a coderef. If the code
 fails to compile, the value will be rejected. Note that this means you accept
 arbitrary code from the user to execute! Please make sure first and foremost
 that this is acceptable in your case. Currently string is eval'ed in the C<main>
 package, without C<use strict> or C<use warnings>.
 
-Coercion from string to regex literal is also available for other forms of
-string.
+Unlike the default behavior of the C<re> Sah type, coercion from other string not
+in the form of C</.../> or C<qr(...)> is not available. Thus, such values will be
+rejected.
 
 This schema is handy if you want to accept regex or coderef from the
 command-line.
