@@ -5,7 +5,7 @@ use strict;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2023-09-09'; # DATE
 our $DIST = 'Sah-Schemas-Re'; # DIST
-our $VERSION = '0.004'; # VERSION
+our $VERSION = '0.005'; # VERSION
 
 1;
 # ABSTRACT: Various regular-expression schemas
@@ -22,7 +22,7 @@ Sah::Schemas::Re - Various regular-expression schemas
 
 =head1 VERSION
 
-This document describes version 0.004 of Sah::Schemas::Re (from Perl distribution Sah-Schemas-Re), released on 2023-09-09.
+This document describes version 0.005 of Sah::Schemas::Re (from Perl distribution Sah-Schemas-Re), released on 2023-09-09.
 
 =head1 SAH SCHEMAS
 
@@ -57,22 +57,23 @@ Regex (convertable from string of the form `E<sol>...E<sol>`) or coderef (conver
 
 Either Regexp object or coderef is accepted.
 
-Coercion from string is available for Regexp If string is of the form of C</.../>
-or C<qr(...)>, then it will be compiled into a Regexp object. If the regex
-pattern inside C</.../> or C<qr(...)> is invalid, value will be rejected.
-Currently, unlike in normal Perl, for the C<qr(...)> form, only parentheses C<(>
-and C<)> are allowed as the delimiter. Currently modifiers C<i>, C<m>, and C<s>
-after the second C</> are allowed.
+Coercion from string for Regexp is available if string is of the form of C</.../>
+or C<qr(...)>; it will be compiled into a Regexp object. If the regex pattern
+inside C</.../> or C<qr(...)> is invalid, value will be rejected. Currently,
+unlike in normal Perl, for the C<qr(...)> form, only parentheses C<(> and C<)> are
+allowed as the delimiter. Currently modifiers C<i>, C<m>, and C<s> after the second
+C</> are allowed.
 
-Coercion from string is available for coderef if string matches the regex
+Coercion from string for coderef is available if string matches the regex
 C<qr/\Asub\s*\{.*\}\z/s>, then it will be eval'ed into a coderef. If the code
 fails to compile, the value will be rejected. Note that this means you accept
 arbitrary code from the user to execute! Please make sure first and foremost
 that this is acceptable in your case. Currently string is eval'ed in the C<main>
 package, without C<use strict> or C<use warnings>.
 
-Coercion from string to regex literal is also available for other forms of
-string.
+Unlike the default behavior of the C<re> Sah type, coercion from other string not
+in the form of C</.../> or C<qr(...)> is not available. Thus, such values will be
+rejected.
 
 This schema is handy if you want to accept regex or coderef from the
 command-line.
